<p align="center">
  <h1 align="center">
    Carbonate SDK
  </h1>
</p>

![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/Carbonate-dev/sdk-python/python-package.yml)

Carbonate turns simple language driven instructions into end-to-end tests. This SDK lets you integrate it directly into your test suite.

Learn more about Carbonate at [https://carbonate.dev](https://carbonate.dev).

## Getting Started

Check out the [getting started guide](https://carbonate.dev/docs/sdk/getting-started/python) for instructions on how to integrate Carbonate into your test suite.

## License
Distributed under the MIT License.
